@@ -20,11 +20,11 @@
 */
 
 #include <config.h>
+#include <libgnomeui/gnome-stock-icons.h>
 
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-main-menu.h"
 #include "gnome-cmd-types.h"
-#include "gnome-cmd-bookmark-dialog.h"
 #include "gnome-cmd-main-win.h"
 #include "gnome-cmd-file-selector.h"
 #include "gnome-cmd-con.h"
@@ -33,6 +33,7 @@
 #include "utils.h"
 #include "imageloader.h"
 #include "gnome-cmd-user-actions.h"
+#include "dialogs/gnome-cmd-manage-bookmarks-dialog.h"
 
 #include "../pixmaps/exec_wheel.xpm"
 
@@ -44,7 +45,7 @@ using namespace std;
    menus. Another difference is that we want only mouse-clicks in the menu to generate an
    action, keyboard shortcuts are caught by the different components by them self */
 
-typedef enum
+enum MenuType
 {
     MENU_TYPE_END,        // No more items, use it at the end of an array
     MENU_TYPE_ITEM,       // Normal item, or radio item if it is inside a radioitems group
@@ -53,10 +54,10 @@ typedef enum
     MENU_TYPE_RADIOITEMS, // Radio item group
     MENU_TYPE_SUBTREE,    // Item that defines a subtree/submenu
     MENU_TYPE_SEPARATOR   // Separator line (menus) or blank space (toolbars)
-} MenuType;
+};
 
 
-typedef struct
+struct MenuData
 {
     MenuType type;          // Type of item
     const gchar *label;     // The text to use for this menu-item
@@ -78,7 +79,7 @@ typedef struct
                                      */
 
     GtkWidget *widget;      // Filled in by gnome_app_create*, you can use this to tweak the widgets once they have been created
-} MenuData;
+};
 
 #define MENUTYPE_END { \
     MENU_TYPE_END, \
@@ -107,14 +108,6 @@ struct GnomeCmdMainMenuPrivate
     GtkWidget *plugins_menu;
     GtkWidget *help_menu;
 
-    GtkWidget *menu_edit_paste;
-    GtkWidget *menu_view_toolbar;
-    GtkWidget *menu_view_conbuttons;
-    GtkWidget *menu_view_concombo;
-    GtkWidget *menu_view_buttonbar;
-    GtkWidget *menu_view_cmdline;
-    GtkWidget *menu_view_hidden_files;
-    GtkWidget *menu_view_backup_files;
     GtkWidget *menu_view_back;
     GtkWidget *menu_view_forward;
 
@@ -153,7 +146,8 @@ static void on_con_list_list_changed (GnomeCmdConList *con_list, GnomeCmdMainMen
 static GtkWidget *create_menu_item (GnomeCmdMainMenu *main_menu, GtkMenu *parent, MenuData *spec)
 {
     GtkWidget *item=NULL;
-    GtkWidget *desc, *shortcut;
+    GtkWidget *desc=NULL;
+    GtkWidget *shortcut=NULL;
     GtkWidget *content = NULL;
     GtkWidget *pixmap = NULL;
 
@@ -162,7 +156,7 @@ static GtkWidget *create_menu_item (GnomeCmdMainMenu *main_menu, GtkMenu *parent
         case MENU_TYPE_BASIC:
             item = gtk_menu_item_new ();
             desc = gtk_label_new_with_mnemonic (spec->label);
-            gtk_widget_ref (desc);
+            g_object_ref (desc);
             gtk_widget_show (desc);
 
             gtk_container_add (GTK_CONTAINER (item), desc);
@@ -170,23 +164,21 @@ static GtkWidget *create_menu_item (GnomeCmdMainMenu *main_menu, GtkMenu *parent
 
         case MENU_TYPE_ITEM:
             item = gtk_image_menu_item_new ();
-            content = create_hbox (GTK_WIDGET (main_win), FALSE, 12);
+            content = create_hbox (*main_win, FALSE, 12);
 
             desc = gtk_label_new_with_mnemonic (spec->label);
-            gtk_widget_ref (desc);
+            g_object_ref (desc);
             gtk_widget_show (desc);
             gtk_box_pack_start (GTK_BOX (content), desc, FALSE, FALSE, 0);
 
-            shortcut = create_label (GTK_WIDGET (main_win), spec->shortcut);
+            shortcut = create_label (*main_win, spec->shortcut);
             gtk_misc_set_alignment (GTK_MISC (shortcut), 1.0, 0.5);
             gtk_box_pack_start (GTK_BOX (content), shortcut, TRUE, TRUE, 0);
 
             if (spec->pixmap_type != 0 && spec->pixmap_info)
             {
-                pixmap = create_ui_pixmap (GTK_WIDGET (main_win),
-                                           spec->pixmap_type,
-                                           spec->pixmap_info,
-                                           GTK_ICON_SIZE_MENU);
+                pixmap = create_ui_pixmap (*main_win, spec->pixmap_type, spec->pixmap_info, GTK_ICON_SIZE_MENU);
+
                 if (pixmap)
                 {
                     gtk_widget_show (pixmap);
@@ -199,8 +191,19 @@ static GtkWidget *create_menu_item (GnomeCmdMainMenu *main_menu, GtkMenu *parent
             break;
 
         case MENU_TYPE_TOGGLEITEM:
-            item = gtk_check_menu_item_new_with_label (spec->label);
-            gtk_signal_connect (GTK_OBJECT (item), "toggled", GTK_SIGNAL_FUNC (spec->moreinfo), spec->user_data);
+            item = gtk_check_menu_item_new ();
+            content = create_hbox (*main_win, FALSE, 12);
+
+            desc = create_label (*main_win, spec->label);
+            gtk_misc_set_alignment (GTK_MISC (desc), 0.0, 0.5);
+            gtk_box_pack_start (GTK_BOX (content), desc, TRUE, TRUE, 0);
+
+            shortcut = create_label (*main_win, spec->shortcut);
+            gtk_misc_set_alignment (GTK_MISC (shortcut), 1.0, 0.5);
+            gtk_box_pack_start (GTK_BOX (content), shortcut, TRUE, TRUE, 0);
+
+            gtk_container_add (GTK_CONTAINER (item), content);
+	    g_signal_connect (item, "toggled", G_CALLBACK (spec->moreinfo), spec->user_data);
             break;
 
         case MENU_TYPE_SEPARATOR:
@@ -218,9 +221,8 @@ static GtkWidget *create_menu_item (GnomeCmdMainMenu *main_menu, GtkMenu *parent
     if (spec->type == MENU_TYPE_ITEM)
     {
         // Connect to the signal and set user data
-        gtk_object_set_data (GTK_OBJECT (item), GNOMEUIINFO_KEY_UIDATA, spec->user_data);
-
-        gtk_signal_connect (GTK_OBJECT (item), "activate", GTK_SIGNAL_FUNC (spec->moreinfo), spec->user_data);
+        g_object_set_data (G_OBJECT (item), GNOMEUIINFO_KEY_UIDATA, spec->user_data);
+        g_signal_connect (item, "activate", G_CALLBACK (spec->moreinfo), spec->user_data);
     }
 
     spec->widget = item;
@@ -236,7 +238,7 @@ static GtkWidget *create_menu (GnomeCmdMainMenu *main_menu, MenuData *spec, Menu
 
     gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), submenu);
 
-    gtk_widget_ref (menu_item);
+    g_object_ref (menu_item);
     gtk_widget_show (menu_item);
 
     for (gint i=0; childs[i].type != MENU_TYPE_END; ++i)
@@ -292,8 +294,8 @@ add_menu_item (GnomeCmdMainMenu *main_menu,
     // Connect to the signal and set user data
     if (callback)
     {
-        gtk_object_set_data (GTK_OBJECT (item), GNOMEUIINFO_KEY_UIDATA, user_data);
-        gtk_signal_connect (GTK_OBJECT (item), "activate", callback, user_data);
+        g_object_set_data (G_OBJECT (item), GNOMEUIINFO_KEY_UIDATA, user_data);
+        g_signal_connect (item, "activate", callback, user_data);
     }
 
     return item;
@@ -357,7 +359,7 @@ static void on_switch_orientation (GtkMenuItem *menu_item, GnomeCmdMainMenu *mai
 {
     gnome_cmd_data.list_orientation = !gnome_cmd_data.list_orientation;
 
-    gnome_cmd_main_win_update_list_orientation (main_win);
+    main_win->update_list_orientation();
 
     update_view_menu (main_menu);
 }
@@ -467,6 +469,25 @@ static void init (GnomeCmdMainMenu *main_menu)
             NULL
         },
         MENUTYPE_SEPARATOR,
+        {
+            MENU_TYPE_ITEM, _("_Search..."), "Alt+F7", NULL,
+            (gpointer) edit_search, NULL,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_FIND,
+            NULL
+        },
+        {
+            MENU_TYPE_ITEM, _("_Quick Search..."), "", NULL,
+            (gpointer) edit_quick_search, NULL,
+            GNOME_APP_PIXMAP_NONE, 0,
+            NULL
+        },
+        {
+            MENU_TYPE_ITEM, _("_Enable Filter..."), "", NULL,
+            (gpointer) edit_filter, NULL,
+            GNOME_APP_PIXMAP_NONE, 0,
+            NULL
+        },
+        MENUTYPE_SEPARATOR,
         {
             MENU_TYPE_ITEM, _("_Diff"), "", NULL,
             (gpointer) file_diff, NULL,
@@ -577,25 +598,6 @@ static void init (GnomeCmdMainMenu *main_menu)
             GNOME_APP_PIXMAP_NONE, 0,
             NULL
         },
-        MENUTYPE_SEPARATOR,
-        {
-            MENU_TYPE_ITEM, _("_Search..."), "Alt+F7", NULL,
-            (gpointer) edit_search, NULL,
-            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_FIND,
-            NULL
-        },
-        {
-            MENU_TYPE_ITEM, _("_Quick Search..."), "", NULL,
-            (gpointer) edit_quick_search, NULL,
-            GNOME_APP_PIXMAP_NONE, 0,
-            NULL
-        },
-        {
-            MENU_TYPE_ITEM, _("_Enable Filter..."), "", NULL,
-            (gpointer) edit_filter, NULL,
-            GNOME_APP_PIXMAP_NONE, 0,
-            NULL
-        },
         MENUTYPE_END
     };
 
@@ -620,6 +622,25 @@ static void init (GnomeCmdMainMenu *main_menu)
             NULL
         },
         MENUTYPE_SEPARATOR,
+        {
+            MENU_TYPE_ITEM, _("Open in New _Tab"), "Ctrl+T", NULL,
+            (gpointer) view_new_tab, NULL,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_OPEN,
+            NULL
+        },
+        {
+            MENU_TYPE_ITEM, _("_Close Tab"), "Ctrl+W", NULL,
+            (gpointer) view_close_tab, NULL,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_CLOSE,
+            NULL
+        },
+        {
+            MENU_TYPE_ITEM, _("Close _All Tabs"), "Ctrl+Shift+W", NULL,
+            (gpointer) view_close_all_tabs, NULL,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_CLOSE,
+            NULL
+        },
+        MENUTYPE_SEPARATOR,
         {
             MENU_TYPE_TOGGLEITEM, _("Show Toolbar"), "", NULL,
             (gpointer) view_toolbar, NULL,
@@ -652,7 +673,7 @@ static void init (GnomeCmdMainMenu *main_menu)
         },
         MENUTYPE_SEPARATOR,
         {
-            MENU_TYPE_TOGGLEITEM, _("Show Hidden Files"), "", NULL,
+            MENU_TYPE_TOGGLEITEM, _("Show Hidden Files"), "Ctrl+Shift+H", NULL,
             (gpointer) view_hidden_files, NULL,
             GNOME_APP_PIXMAP_NONE, NULL,
             NULL
@@ -670,6 +691,12 @@ static void init (GnomeCmdMainMenu *main_menu)
             GNOME_APP_PIXMAP_NONE, NULL,
             NULL
         },
+        {
+            MENU_TYPE_ITEM, _("Maximize Panel Size"), "", NULL,
+            (gpointer) view_maximize_pane, NULL,
+            GNOME_APP_PIXMAP_NONE, NULL,
+            NULL
+        },
         MENUTYPE_END
     };
 
@@ -717,12 +744,6 @@ static void init (GnomeCmdMainMenu *main_menu)
             GNOME_APP_PIXMAP_STOCK, GTK_STOCK_ITALIC,
             NULL
         },
-        {
-            MENU_TYPE_ITEM, _("_MIME Types..."), "", NULL,
-            (gpointer) options_edit_mime_types, NULL,
-            GNOME_APP_PIXMAP_NONE, 0,
-            NULL
-        },
         MENUTYPE_END
     };
 
@@ -746,7 +767,7 @@ static void init (GnomeCmdMainMenu *main_menu)
     MenuData help_menu_uiinfo[] =
     {
         {
-            MENU_TYPE_ITEM, _("_Contents"), "F1", NULL,
+            MENU_TYPE_ITEM, _("_Documentation"), "F1", NULL,
             (gpointer) help_help, NULL,
             GNOME_APP_PIXMAP_STOCK, GTK_STOCK_HELP,
             NULL
@@ -830,41 +851,18 @@ static void init (GnomeCmdMainMenu *main_menu)
     main_menu->priv->help_menu = create_menu (main_menu, &spec, help_menu_uiinfo);
     gtk_menu_shell_append (GTK_MENU_SHELL (main_menu), main_menu->priv->help_menu);
 
-    main_menu->priv->menu_edit_paste = edit_menu_uiinfo[2].widget;
     main_menu->priv->menu_view_back = view_menu_uiinfo[0].widget;
     main_menu->priv->menu_view_forward = view_menu_uiinfo[1].widget;
-    main_menu->priv->menu_view_toolbar = view_menu_uiinfo[4].widget;
-    main_menu->priv->menu_view_conbuttons = view_menu_uiinfo[5].widget;
-    main_menu->priv->menu_view_concombo = view_menu_uiinfo[6].widget;
-    main_menu->priv->menu_view_cmdline = view_menu_uiinfo[7].widget;
-    main_menu->priv->menu_view_buttonbar = view_menu_uiinfo[8].widget;
-    main_menu->priv->menu_view_hidden_files = view_menu_uiinfo[10].widget;
-    main_menu->priv->menu_view_backup_files = view_menu_uiinfo[11].widget;
 
-    gtk_check_menu_item_set_active (
-        GTK_CHECK_MENU_ITEM (main_menu->priv->menu_view_toolbar),
-        gnome_cmd_data.toolbar_visibility);
-    gtk_check_menu_item_set_active (
-        GTK_CHECK_MENU_ITEM (main_menu->priv->menu_view_conbuttons),
-        gnome_cmd_data.conbuttons_visibility);
-    gtk_check_menu_item_set_active (
-        GTK_CHECK_MENU_ITEM (main_menu->priv->menu_view_concombo),
-        gnome_cmd_data.concombo_visibility);
-    gtk_check_menu_item_set_active (
-        GTK_CHECK_MENU_ITEM (main_menu->priv->menu_view_cmdline),
-        gnome_cmd_data.cmdline_visibility);
-    gtk_check_menu_item_set_active (
-        GTK_CHECK_MENU_ITEM (main_menu->priv->menu_view_buttonbar),
-        gnome_cmd_data.buttonbar_visibility);
-    gtk_check_menu_item_set_active (
-        GTK_CHECK_MENU_ITEM (main_menu->priv->menu_view_hidden_files),
-        !gnome_cmd_data.filter_settings.hidden);
-    gtk_check_menu_item_set_active (
-        GTK_CHECK_MENU_ITEM (main_menu->priv->menu_view_backup_files),
-        !gnome_cmd_data.filter_settings.backup);
+    gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (view_menu_uiinfo[8].widget), gnome_cmd_data.toolbar_visibility);
+    gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (view_menu_uiinfo[9].widget), gnome_cmd_data.conbuttons_visibility);
+    gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (view_menu_uiinfo[10].widget), gnome_cmd_data.concombo_visibility);
+    gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (view_menu_uiinfo[11].widget), gnome_cmd_data.cmdline_visibility);
+    gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (view_menu_uiinfo[12].widget), gnome_cmd_data.buttonbar_visibility);
+    gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (view_menu_uiinfo[14].widget), !gnome_cmd_data.options.filter.hidden);
+    gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (view_menu_uiinfo[15].widget), !gnome_cmd_data.options.filter.backup);
 
-    gtk_signal_connect (GTK_OBJECT (gnome_cmd_con_list_get ()), "list-changed",
-                        GTK_SIGNAL_FUNC (on_con_list_list_changed), main_menu);
+    g_signal_connect (gnome_cmd_con_list_get (), "list-changed", G_CALLBACK (on_con_list_list_changed), main_menu);
 
     gnome_cmd_main_menu_update_bookmarks (main_menu);
     gnome_cmd_main_menu_update_connections (main_menu);
@@ -878,7 +876,7 @@ static void init (GnomeCmdMainMenu *main_menu)
 
 GtkWidget *gnome_cmd_main_menu_new ()
 {
-    return (GtkWidget *) gtk_type_new (gnome_cmd_main_menu_get_type ());
+    return (GtkWidget *) g_object_new (GNOME_CMD_TYPE_MAIN_MENU, NULL);
 }
 
 
@@ -924,7 +922,7 @@ void gnome_cmd_main_menu_update_connections (GnomeCmdMainMenu *main_menu)
     GtkMenuShell *connections_menu = GTK_MENU_SHELL (GTK_MENU_ITEM (main_menu->priv->connections_menu)->submenu);
     GnomeCmdConList *con_list = gnome_cmd_con_list_get ();
     GList *all_cons = gnome_cmd_con_list_get_all (con_list);
-    // GList *ftp_cons = gnome_cmd_con_list_get_all_ftp (con_list);
+    // GList *remote_cons = gnome_cmd_con_list_get_all_remote (con_list);
     // GList *dev_cons = gnome_cmd_con_list_get_all_dev (con_list);
 
     // Remove all old items
@@ -938,10 +936,10 @@ void gnome_cmd_main_menu_update_connections (GnomeCmdMainMenu *main_menu)
     // Add all open connections
     gint match_count = 0;
 
-    for (GList *tmp = all_cons; tmp; tmp = tmp->next)
+    for (GList *i = all_cons; i; i = i->next)
     {
-        GnomeCmdCon *con = GNOME_CMD_CON (tmp->data);
-        if (!GNOME_CMD_IS_CON_FTP (con) || gnome_cmd_con_is_open (con))
+        GnomeCmdCon *con = GNOME_CMD_CON (i->data);
+        if (!GNOME_CMD_IS_CON_REMOTE (con) || gnome_cmd_con_is_open (con))
         {
             add_connection (main_menu, con,
                             gnome_cmd_con_get_go_text (con),
@@ -958,9 +956,9 @@ void gnome_cmd_main_menu_update_connections (GnomeCmdMainMenu *main_menu)
             add_separator (main_menu, connections_menu));
 
     // Add all open connections that are not permanent
-    for (GList *tmp = all_cons; tmp; tmp = tmp->next)
+    for (GList *i = all_cons; i; i = i->next)
     {
-        GnomeCmdCon *con = GNOME_CMD_CON (tmp->data);
+        GnomeCmdCon *con = GNOME_CMD_CON (i->data);
         if (gnome_cmd_con_is_closeable (con) && gnome_cmd_con_is_open (con))
             add_connection (main_menu, con,
                             gnome_cmd_con_get_close_text (con),
@@ -1001,7 +999,7 @@ void gnome_cmd_main_menu_update_sens (GnomeCmdMainMenu *main_menu)
 {
     g_return_if_fail (GNOME_CMD_IS_MAIN_MENU (main_menu));
 
-    GnomeCmdFileSelector *fs = gnome_cmd_main_win_get_fs (main_win, ACTIVE);
+    GnomeCmdFileSelector *fs = main_win->fs(ACTIVE);
 
     gtk_widget_set_sensitive (main_menu->priv->menu_view_back, fs->can_back());
     gtk_widget_set_sensitive (main_menu->priv->menu_view_forward, fs->can_forward());
@@ -1012,7 +1010,7 @@ static void on_plugin_menu_activate (GtkMenuItem *item, PluginData *data)
 {
     g_return_if_fail (data != NULL);
 
-    GnomeCmdState *state = gnome_cmd_main_win_get_state (main_win);
+    GnomeCmdState *state = main_win->get_state();
     gnome_cmd_plugin_update_main_menu_state (data->plugin, state);
 }
 
@@ -1021,5 +1019,5 @@ void gnome_cmd_main_menu_add_plugin_menu (GnomeCmdMainMenu *main_menu, PluginDat
 {
     gtk_menu_shell_append (GTK_MENU_SHELL (GTK_MENU_ITEM (main_menu->priv->plugins_menu)->submenu), data->menu);
 
-    gtk_signal_connect (GTK_OBJECT (data->menu), "activate", GTK_SIGNAL_FUNC (on_plugin_menu_activate), data);
+    g_signal_connect (data->menu, "activate", G_CALLBACK (on_plugin_menu_activate), data);
 }
